/*
 * MacSamba
 * <http://ghostwood.org/software/macSamba.html>
 * Copyright 2006-2015 Nick Howes <nick@ghostwood.org>
 * tabs every 4 spaces
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; version 2
 * of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */


#include <stdio.h>
#include "devices.h"

static deviceInfo_t deviceInfo[] = {
//		name				id				ext
	{	"SAME70Q21",		0xA1020E00,		0x00000002 },
	{	"SAME70Q20",		0xA1020C00,		0x00000002 },
	{	"SAME70Q19",		0xA10D0A00,		0x00000002 },
	{	"SAME70N21",		0xA1020E00,		0x00000001 },
	{	"SAME70N20",		0xA1020C00,		0x00000001 },
	{	"SAME70N19",		0xA10D0A00,		0x00000001 },
	{	"SAME70J21",		0xA1020E00,		0x00000000 },
	{	"SAME70J20",		0xA1020C00,		0x00000000 },
	{	"SAME70J19",		0xA10D0A00,		0x00000000 },
	{	"SAMS70Q21",		0xA1120E00,		0x00000002 },
	{	"SAMS70Q20",		0xA1120C00,		0x00000002 },
	{	"SAMS70Q19",		0xA11D0A00,		0x00000002 },
	{	"SAMS70N21",		0xA1120E00,		0x00000001 },
	{	"SAMS70N20",		0xA1120C00,		0x00000001 },
	{	"SAMS70N19",		0xA11D0A00,		0x00000001 },
	{	"SAMS70J21",		0xA1120E00,		0x00000000 },
	{	"SAMS70J20",		0xA1120C00,		0x00000000 },
	{	"SAMS70J19",		0xA11D0A00,		0x00000000 },
	{	"SAMV71Q21",		0xA1220E00,		0x00000002 },
	{	"SAMV71Q20",		0xA1220C00,		0x00000002 },
	{	"SAMV71Q19",		0xA12D0A00,		0x00000002 },
	{	"SAMV71N21",		0xA1220E00,		0x00000001 },
	{	"SAMV71N20",		0xA1220C00,		0x00000001 },
	{	"SAMV71N19",		0xA12D0A00,		0x00000001 },
	{	"SAMV71J21",		0xA1220E00,		0x00000000 },
	{	"SAMV71J20",		0xA1220C00,		0x00000000 },
	{	"SAMV71J19",		0xA12D0A00,		0x00000000 },
	{	"SAMV70Q20",		0xA1320C00,		0x00000002 },
	{	"SAMV70Q19",		0xA13D0A00,		0x00000002 },
	{	"SAMV70N20",		0xA1320C00,		0x00000001 },
	{	"SAMV70N19",		0xA13D0A00,		0x00000001 },
	{	"SAMV70J20",		0xA1320C00,		0x00000000 },
	{	"SAMV70J19",		0xA13D0A00,		0x00000000 }
};

#define DEV_INFO_COUNT (sizeof(deviceInfo) / sizeof(struct deviceInfoStruct))


deviceInfo_t* getDeviceByID(unsigned int idCode, unsigned int extCode) {
	int i;
	deviceInfo_t* ptr = deviceInfo;

	for (i=0 ; i<DEV_INFO_COUNT ; i++) {
		if ( (ptr->idCode == idCode) && (ptr->extCode == extCode) ) return ptr;
		ptr++;
	}
	return NULL;
}


int getFlashPageCount(deviceInfo_t* dev) {
	switch (dev->idCode & 0x00000F00) {	//NVPSIZ field of CHIPID
		case 0x00000A00 : return 1024; //512k = 1024 * 512B
		case 0x00000C00 : return 2048; //1M = 2048 * 512B
		case 0x00000E00 : return 4096; //2M = 4096 * 512B
		default: return -1;
	}
	
}